getTaxonomyName: Return the exact taxonomy name for list of protein

View source: R/utility.R

getTaxonomyNameR Documentation

Return the exact taxonomy name for list of protein

Description

getTaxonomyName get a character vector of proteins with their UniProt accession code and returns the exact taxonomy code.

Usage

getTaxonomyName(x)

Arguments

x

A character vector with each entry presenting a protein UniProt accession code.

Value

The exact taxonomy name

Examples

getTaxonomyName(x = exmplData1$pl1)

PEIMAN2 documentation built on Feb. 16, 2026, 9:06 a.m.