This function takes proteins with their UniProt accession code, runs singular enrichment (SEA) analysis, and returns enrichment results.
runEnrichment(protein, os.name, blist = NULL, p.adj.method = "BH")The result is a dataframe with the following columns:
PTM: Post-translational modification (PTM) keyword
FreqinUniprot: The total number of proteins in UniProt with this PTM.
FreqinList: The total number of proteins in the given list with this PTM.
Sample: Number of proteins in the given list.
Population: Total number of proteins in the current version of PEIMAN database with this PTM.
pvalue: The p-value obtained from hypergeometric test (enrichment analysis).
corrected pvalue: Adjusted p-value to correct for multiple testing.
AC: Uniprot accession code (AC) of proteins with each PTM.
A character vector with protein UniProt accession codes.
A character vector of length one with exact taxonomy name of
species. If you do not know the the exact taxonomy name of species you are
working with, please read getTaxonomyName.
The background list will be substituted with the complete set of UniProt reviewed proteins to facilitate the analysis with a background list. The default value is NULL. Alternatively, if a vector of UniProt Accession Codes is provided, it will serve as the background list for the enrichment analysis.
The adjustment method to correct for multiple testing.
The default value is 'BH'. Run/see p.adjust.methods to
get a list of possible methods.
enrich1 <- runEnrichment(protein = exmplData1$pl1, os.name = 'Homo sapiens (Human)')
Run the code above in your browser using DataLab